@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
+import six
 import unittest
 
 import requests
 import api_toolkit
-from helpers import use_cassette as use_pw_cassette
+from .helpers import use_cassette as use_pw_cassette
 
 from passaporte_web.main import Application, ServiceAccount, Account, Identity
 from passaporte_web.tests.helpers import TEST_USER, APP_CREDENTIALS
@@ -34,7 +35,7 @@ class ApplicationUsersTest(unittest.TestCase):
 
     def test_application_users_are_not_iterable(self):
         app_users = self.app.users.all()
-        self.assertRaises(ValueError, app_users.next)
+        self.assertRaises(ValueError, six.next, app_users)
 
     def test_application_users_can_be_created(self):
         user_data = {
@@ -147,8 +148,8 @@ class ApplicationUsersTest(unittest.TestCase):
             user = self.app.users.get(email=TEST_USER['email'])
 
         self.assertTrue(isinstance(user, Identity))
-        self.assertEquals(user.email, TEST_USER['email'])
-        self.assertEquals(len(list(user.accounts.from_seed())), 5)
+        self.assertEqual(user.email, TEST_USER['email'])
+        self.assertEqual(len(list(user.accounts.from_seed())), 5)
 
     def test_get_user_by_email_fails_when_email_is_not_registered(self):
         with use_pw_cassette('user/get_by_unknown_email'):
@@ -159,30 +160,30 @@ class ApplicationUsersTest(unittest.TestCase):
             user = self.app.users.get(uuid=TEST_USER['uuid'])
 
         self.assertTrue(isinstance(user, Identity))
-        self.assertEquals(user.email, TEST_USER['email'])
-        self.assertEquals(len(list(user.accounts.from_seed())), 4)
+        self.assertEqual(user.email, TEST_USER['email'])
+        self.assertEqual(len(list(user.accounts.from_seed())), 4)
 
     def test_get_user_including_expired_accounts(self):
         with use_pw_cassette('user/get_user_including_expired_accounts'):
             user = self.app.users.get(email=TEST_USER['email'], include_expired_accounts=True)
 
         self.assertTrue(isinstance(user, Identity))
-        self.assertEquals(user.email, TEST_USER['email'])
-        self.assertEquals(len(list(user.accounts.from_seed())), 8)
+        self.assertEqual(user.email, TEST_USER['email'])
+        self.assertEqual(len(list(user.accounts.from_seed())), 8)
 
     def test_get_user_including_accounts_from_other_services(self):
         with use_pw_cassette('user/get_user_including_other_services'):
             user = self.app.users.get(email=TEST_USER['email'], include_other_services=True)
 
         self.assertTrue(isinstance(user, Identity))
-        self.assertEquals(user.email, TEST_USER['email'])
-        self.assertEquals(len(list(user.accounts.from_seed())), 6)
+        self.assertEqual(user.email, TEST_USER['email'])
+        self.assertEqual(len(list(user.accounts.from_seed())), 6)
 
         service_accounts = [item for item in user.accounts.from_seed() if isinstance(item, ServiceAccount)]
         external_accounts = [item for item in user.accounts.from_seed() if isinstance(item, Account)]
 
-        self.assertEquals(len(service_accounts), 5)
-        self.assertEquals(len(external_accounts), 1)
+        self.assertEqual(len(external_accounts), 1)
+        self.assertEqual(len(service_accounts), 5)
 
     def test_get_user_by_uuid_fails_when_uuid_is_not_registered(self):
         with use_pw_cassette('user/get_by_unknown_uuid'):
@@ -198,9 +199,9 @@ class ApplicationUsersTest(unittest.TestCase):
     def test_authenticate_user_with_email_and_password(self):
         with use_pw_cassette('user/authenticate_with_email_and_password'):
             user = self.app.users.authenticate(email=TEST_USER['email'], password=TEST_USER['password'])
-        
+
         self.assertTrue(isinstance(user, Identity))
-        self.assertEquals(user.uuid, TEST_USER['uuid'])
+        self.assertEqual(user.uuid, TEST_USER['uuid'])
 
     def test_authenticate_user_with_email_and_wrong_password(self):
         with use_pw_cassette('user/authenticate_with_email_and_wrong_password'):
@@ -212,9 +213,9 @@ class ApplicationUsersTest(unittest.TestCase):
     def test_authenticate_user_with_id_token(self):
         with use_pw_cassette('user/authenticate_with_id_token'):
             user = self.app.users.authenticate(id_token=TEST_USER['id_token'])
-        
+
         self.assertTrue(isinstance(user, Identity))
-        self.assertEquals(user.uuid, TEST_USER['uuid'])
+        self.assertEqual(user.uuid, TEST_USER['uuid'])
 
     def test_authenticate_user_with_invalid_id_token(self):
         with use_pw_cassette('user/authenticate_with_invalid_id_token'):
@@ -223,8 +224,8 @@ class ApplicationUsersTest(unittest.TestCase):
     def test_user_credentials_are_replaced_by_app_credentials_in_session(self):
         with use_pw_cassette('user/authenticate_with_email_and_password'):
             user = self.app.users.authenticate(email=TEST_USER['email'], password=TEST_USER['password'])
-        
-        self.assertEquals(user._session.auth, (
+
+        self.assertEqual(user._session.auth, (
             APP_CREDENTIALS['token'], APP_CREDENTIALS['secret']
         ))
 
@@ -236,7 +237,7 @@ class CanLoadServiceAccounts(unittest.TestCase):
         with use_pw_cassette('application/account_list'):
             app_accounts = list(self.app.accounts.all())
 
-        self.assertEquals(len(app_accounts), 26)
+        self.assertEqual(len(app_accounts), 26)
         for item in app_accounts:
             self.assertTrue(isinstance(item, ServiceAccount))
 
@@ -244,16 +245,16 @@ class CanLoadServiceAccounts(unittest.TestCase):
         with use_pw_cassette('application/empty_account_list'):
             accounts = list(self.app.accounts.all())
 
-        self.assertEquals(len(accounts), 0)
+        self.assertEqual(len(accounts), 0)
 
     def test_load_using_invalid_credentials(self):
         with use_pw_cassette('accounts/using_invalid_credentials'):
             self.app.accounts._session.auth = ('invalid', 'credentials')
-            self.assertRaises(requests.HTTPError, self.app.accounts.all().next)
+            self.assertRaises(requests.HTTPError, six.next, self.app.accounts.all())
 
     def test_load_for_application_without_permissions(self):
         with use_pw_cassette('accounts/application_without_permissions'):
-            self.assertRaises(requests.HTTPError, self.app.accounts.all().next)
+            self.assertRaises(requests.HTTPError, six.next, self.app.accounts.all())
 
 
 class ApplicationAccountsTest(CanGetServiceAccount, CanLoadServiceAccounts):
@@ -269,14 +270,14 @@ class ApplicationAccountsTest(CanGetServiceAccount, CanLoadServiceAccounts):
 
     def test_application_accounts_cannot_be_deleted(self):
         with use_pw_cassette('application/account_list'):
-            first_account = self.app.accounts.all().next()
+            first_account = six.next(self.app.accounts.all())
             first_account.load_options()
 
         self.assertRaises(ValueError, first_account.delete)
 
     def test_application_accounts_can_be_updated(self):
         with use_pw_cassette('application/account_list'):
-            first_account = self.app.accounts.all().next()
+            first_account = six.next(self.app.accounts.all())
             first_account.load_options()
 
         with use_pw_cassette('accounts/update_with_same_data'):
